@@ -93,7 +93,7 @@ forecast.hybridModel <- function(object,
     if(min(level) > 0 && max(level) < 1){
       level <- 100 * level
     } else if(min(level) < 0 || max(level) > 99.99){
-      stop("Confidence limit out of range")
+      stop("Prediction interval out of range")
     }
   }
 
@@ -106,7 +106,12 @@ forecast.hybridModel <- function(object,
   forecasts$pointForecasts <- matrix(numeric(), nrow = h, ncol = length(includedModels))
   colnames(forecasts$pointForecasts) <- includedModels
   if("auto.arima" %in% includedModels){
-    forecasts$auto.arima <- forecast(object$auto.arima, h = h, xreg = xreg, level = level, ...)
+    # Only apply the xreg if it was used in the original model
+    xregA <- xreg
+    if(!object$xreg$auto.arima){
+      xregA <- NULL
+      }
+    forecasts$auto.arima <- forecast(object$auto.arima, h = h, xreg = xregA, level = level, ...)
     forecasts$pointForecasts[, "auto.arima"] <- forecasts$auto.arima$mean
   }
   if("ets" %in% includedModels){
@@ -118,11 +123,22 @@ forecast.hybridModel <- function(object,
      forecasts$pointForecasts[, "thetam"] <- forecasts$thetam$mean
   }
   if("nnetar" %in% includedModels){
-    forecasts$nnetar <- forecast(object$nnetar, h = h, xreg = xreg, PI = PI, level = level, ...)
+    # Only apply the xreg if it was used in the original model
+    xregN <- xreg
+    if(!object$xreg$nnetar){
+      xregN <- NULL
+      }
+    forecasts$nnetar <- forecast(object$nnetar, h = h, xreg = xregN, PI = PI, level = level, ...)
     forecasts$pointForecasts[, "nnetar"] <- forecasts$nnetar$mean
   }
   if("stlm" %in% includedModels){
-    forecasts$stlm <- forecast(object$stlm, h = h, xreg = xreg, level = level, ...)
+    # Only apply the xreg if it was used in the original model
+    xregS <- xreg
+    # xreg is only used in stlm if method = "arima"
+    if(!object$xreg$stlm){
+      xregS <- NULL
+      }
+    forecasts$stlm <- forecast(object$stlm, h = h, xreg = xregS, level = level, ...)
     forecasts$pointForecasts[, "stlm"] <- forecasts$stlm$mean
   }
   if("tbats" %in% includedModels){
